@@ -7,7 +7,7 @@ if __name__ == "__main__":
     # We start a connection to the robot
     # and can now read from and write to the robot via the variable "durin"
     #with Durin("durin5.local", enable_dvs=True) as durin:
-    with Durin("172.16.222.200", enable_control=False, enable_dvs=True) as durin:
+    with Durin("durin0.local") as durin:
 
         # Loop forever
         while True:
@@ -16,9 +16,9 @@ if __name__ == "__main__":
             # - obs = Robot sensor observations
             # - dvs = Robot DVS data (if any)
             # - cmd = Robot responses to commands
-            (obs, dvs, cmd) = durin.read()
-            if dvs is not None:
-                print(dvs.sum())
+            # (obs, dvs, cmd) = durin.read()
+            # if dvs is not None:
+            #     print(dvs.sum())
 
             # Move following a square-shaped trajectory
             durin(Move(100, 0, 0))
